import React, { useCallback, useEffect, useMemo, useState } from 'react'
import { Modal, Form, Input, Divider, Select, Radio, DatePicker, Switch } from 'antd'
import { SiteSetEnum, PromotedObjectType } from '@/services/launchAdq/enum'
import { ModalConfig } from '.'
import styles from './index.less'
import { adcreativeTemplateList } from '../adenum';
interface Props {
    title?: string,
    visible: boolean,
    PupFn: (arg: ModalConfig) => void,
    callback: (params: any) => void,
    confirmLoading: boolean
}
/**创意模板*/
function CreativeModal(props: Props) {
    let { visible, title, confirmLoading, PupFn, callback } = props
    const [form] = Form.useForm();
    const [pupState, setPupState] = useState({
        kp_show: false,
        xd_show: false,
        sj_show: false,
        bq_show: false,
        sp_show: false
    })
    const [conversionList, setConversionList] = useState<any>(null)
    let pageType = Form.useWatch('pageType', form)
    let adcreativeTemplateId = Form.useWatch('adcreativeTemplateId', form)
    let actionBtn = Form.useWatch('actionBtn', form)
    let siteSet = Form.useWatch('siteSet', form)
    let promotedObjectType = Form.useWatch('promotedObjectType', form)
    let adcreativeElementsType = Form.useWatch('adcreativeElementsType', form)
    let dataShow = Form.useWatch('dataShow', form)
    let conversionDataType = Form.useWatch('conversionDataType', form)

    // 确定事件
    const handleOk = useCallback(() => {
        form.validateFields().then(values => {
            let newValues = JSON.parse(JSON.stringify(values))
            console.log(newValues)
            // callback(newValues)
        })
        // PupFn({ visible: false })
    }, [form])
    //获取对应创意形式列表
    const adcreativeTemplateArr = useMemo(() => {
        if (siteSet?.length > 0 && promotedObjectType && adcreativeElementsType) {
            let arr = adcreativeTemplateList.filter(item => {
                if (item.adcreative_template_style === adcreativeElementsType && item.promoted_object_type === promotedObjectType && siteSet.some((s: string) => item.site_set.some(i => s === i))) {
                    return item
                }
                return null
            })
            return arr
        }
        return null
    }, [siteSet, promotedObjectType, adcreativeElementsType])
    // 获取对应落地页按钮
    const pageTypeList = useMemo(() => {
        if (adcreativeTemplateId) {
            let arr: any = adcreativeTemplateArr?.filter(item => item.adcreative_template_id === adcreativeTemplateId)[0]?.landing_page_config.support_page_type_list
            return arr
        }
        return null

    }, [adcreativeTemplateId, adcreativeTemplateArr])
    // 获取对应行动按钮数据
    const linkNameList = useMemo(() => {
        if (pageType) {
            let arr = (pageTypeList?.filter((item: { page_type: any; }) => item.page_type === pageType)[0] as any)?.support_link_name_type?.list
            return arr
        }
        return null
    }, [pageType, pageTypeList])
    // 跳转落地页
    const linkPageList = useMemo(() => {
        if (pageType) {
            let arr = (pageTypeList?.filter((item: { page_type: any; }) => item.page_type === pageType)[0] as any)?.support_link_page_type?.list
            return arr
        }
        return null
    }, [pageType, pageTypeList])


    // 切换形式类型
    useEffect(() => {
        //默认选第一个选项
        if (Array.isArray(adcreativeTemplateArr)) {
            let values = {}
            let adcreativeTemplateId = adcreativeTemplateArr[0]?.adcreative_template_id
            let pageList = adcreativeTemplateArr?.filter(item => item.adcreative_template_id === adcreativeTemplateArr[0]?.adcreative_template_id)[0]?.landing_page_config.support_page_type_list
            let pageType = pageList[0]?.page_type
            //卡片组件存在
            if (adcreativeTemplateArr[0]?.kp_show) {

            }
            //行动按钮组件存在
            if (adcreativeTemplateArr[0]?.xd_show) {
                let linkNameList = (pageList?.filter((item: { page_type: any; }) => item.page_type === pageType)[0] as any)?.support_link_name_type?.list
                let linkPageList = (pageList?.filter((item: { page_type: any; }) => item.page_type === pageType)[0] as any)?.support_link_page_type?.list
                let linkNameType = linkNameList[0]?.link_name_type
                let linkPageType = linkPageList[0]?.link_page_type
                values = { ...values, linkNameType, linkPageType }
            }

            //标签组件
            if (adcreativeTemplateArr[0]?.bq_show) {

            }
            //视频结束页组件
            if (adcreativeTemplateArr[0]?.sp_show) {

            }
            values = { ...values, adcreativeTemplateId, pageType }
            form.setFieldsValue(values)
        }
    }, [adcreativeTemplateArr, form])
    //每次选中创意设置该展示的界面
    useEffect(() => {
        if (adcreativeTemplateId && Array.isArray(adcreativeTemplateArr)) {
            let adcreativeTemplate = adcreativeTemplateArr?.filter(item => item.adcreative_template_id === adcreativeTemplateId)[0]
            //数据展示组件
            if (adcreativeTemplate?.sj_show) {
                let arr = (adcreativeTemplate.adcreative_attributes as any)?.filter((item: { name: string; }) => item.name === 'conversion_data_type' || item.name === 'conversion_target_type')
                let newObj: any = {}
                arr.forEach((item: { name: string | number; property_detail: { enum_detail: { enumeration: any[]; }; }; }) => {
                    newObj[item.name] = item.property_detail.enum_detail.enumeration.filter((i: { category: any; }) => !i.category)
                })
                setConversionList(newObj)
                form.setFieldsValue({
                    conversionDataType: newObj.conversion_data_type[0].value,
                    conversionTargetType: newObj.conversion_target_type[0].value
                })
            }
            setPupState({
                kp_show: !!adcreativeTemplate?.kp_show,//卡片组件
                xd_show: !!adcreativeTemplate?.xd_show,//行动按钮组件
                sj_show: !!adcreativeTemplate?.sj_show,//数据展示组件
                bq_show: !!adcreativeTemplate?.bq_show,//标签组件
                sp_show: !!adcreativeTemplate?.sp_show//视频结束页组件
            })
        }
    }, [adcreativeTemplateArr, adcreativeTemplateId])

    return <Modal
        visible={visible}
        title={title + '创意'}
        onCancel={() => { PupFn({ visible: false }) }}
        onOk={handleOk}
        width={900}
        confirmLoading={confirmLoading}
    >
        <Form
            form={form}
            labelCol={{ span: 3 }}
            initialValues={
                {
                    adcreativeElementsType: '视频',
                    promotedObjectType: 'PROMOTED_OBJECT_TYPE_WECHAT_OFFICIAL_ACCOUNT',
                    siteSet: ['SITE_SET_MOMENTS'],
                    actionBtn: true,//行动按钮
                    dataShow: true,//数据展示
                }
            }
        >
            {/* ============================================================基本信息============================================================= */}
            <Divider orientation='center'>基本信息</Divider>
            {/* ============================================================创意名称============================================================= */}
            <Form.Item label={<strong>创意名称</strong>} name='adcreativeName' rules={[{ required: true, message: '请输入广告名称!' }]}>
                <Input placeholder='创意名称' style={{ width: 300 }} />
            </Form.Item>
            {/* ============================================================推广目标类型============================================================= */}
            <Form.Item label={<strong>推广目标类型</strong>} name='promotedObjectType' rules={[{ required: true, message: '请选择推广告推广目标类型!' }]}>
                <Select style={{ width: 300 }} showSearch filterOption={(input, option) =>
                    (option!.children as unknown as string).toLowerCase().includes(input.toLowerCase())
                } allowClear>
                    {
                        Object.keys(PromotedObjectType).map(key => {
                            return <Select.Option value={key} key={key}>{PromotedObjectType[key]}</Select.Option>
                        })
                    }
                </Select>
            </Form.Item>
            {/* ============================================================投放版位============================================================= */}
            <Form.Item label={<strong>投放版位</strong>} name='siteSet' rules={[{ required: true, message: '请输入选择广告版位！' }]}>
                <Select mode='multiple' style={{ width: 300 }} allowClear>
                    {
                        Object.keys(SiteSetEnum).map(key => {
                            return <Select.Option value={key} key={key}>{SiteSetEnum[key]}</Select.Option>
                        })
                    }
                </Select>
            </Form.Item>
            {/* ============================================================创意形式============================================================= */}
            <Divider orientation='center'>创意形式</Divider>
            {/* ============================================================创意形式============================================================= */}
            <Form.Item label={<strong>创意形式</strong>} name='adcreativeElementsType'>
                <Radio.Group >
                    <Radio.Button value="视频">视频</Radio.Button>
                    <Radio.Button value="图片">图片</Radio.Button>
                </Radio.Group>
            </Form.Item>
            <Form.Item style={{ marginLeft: 107 }} name='adcreativeTemplateId'>
                <Radio.Group className={styles.adcreative_template}>
                    {
                        adcreativeTemplateArr?.map((item, index) => {
                            return <Radio.Button value={item.adcreative_template_id} key={item.adcreative_template_id}>
                                <div className={styles.adcreative_template_item}>
                                    <img src={item.adcreative_sample_image} />
                                    <span>{item.adcreative_template_appellation} </span>
                                </div>
                            </Radio.Button>
                        })
                    }
                </Radio.Group>
            </Form.Item>
            {/* ============================================================创意内容============================================================= */}
            <Divider orientation='center'>创意内容</Divider>
             {/* ============================================================素材============================================================= */}
             
            {/* ============================================================落地页============================================================= */}
            <Form.Item label={<strong>落地页</strong>} name='pageType'>
                <Radio.Group>
                    {
                        pageTypeList?.map((item: { page_type: string | number | null | undefined; description: boolean | React.ReactChild | React.ReactFragment | React.ReactPortal | null | undefined; }, index: number) => {
                            if (!pageType && index === 0) {

                            }
                            return <Radio.Button value={item.page_type} key={item.page_type}>{item.description}</Radio.Button>
                        })
                    }
                </Radio.Group>
            </Form.Item>
            {/* ============================================================行动按钮============================================================= */}
            {
                pupState.xd_show && <Form.Item label={<strong>行动按钮</strong>} name='actionBtn' valuePropName="checked">
                    <Switch checkedChildren="开启" unCheckedChildren="关闭" />
                </Form.Item>
            }
            {
                actionBtn && <>
                    <div style={{ display: 'flex' }}>
                        <p style={{ marginBottom: 5, marginLeft: 107 }}><strong style={{ marginRight: 20 }}>按钮文案</strong></p>
                        <Form.Item name='linkNameType'>
                            <Select style={{ width: 200 }} showSearch filterOption={(input, option) =>
                                (option!.children as unknown as string).toLowerCase().includes(input.toLowerCase())
                            } allowClear>
                                {
                                    linkNameList?.map((item: { link_name_type: string; description: string; }, index: number) => {
                                        return <Select.Option value={item.link_name_type} key={item.link_name_type}>{item.description}</Select.Option>
                                    })
                                }
                            </Select>
                        </Form.Item>
                    </div>
                    <div style={{ display: 'flex' }}>
                        <p style={{ marginBottom: 5, marginLeft: 107 }}><strong style={{ marginRight: 20 }}>跳转落地页</strong></p>
                        <Form.Item name='linkPageType'>
                            <Radio.Group>
                                {
                                    linkPageList?.map((item: { link_page_type: string; description: string; }, index: number) => {
                                        return <Radio.Button value={item.link_page_type} key={item.link_page_type}>{item.description}</Radio.Button>
                                    })
                                }
                            </Radio.Group>
                        </Form.Item>
                    </div>
                </>
            }
            {/* ============================================================数据展示============================================================= */}
            {pupState.sj_show && <Form.Item label={<strong>数据展示</strong>} name='dataShow' valuePropName="checked">
                <Switch checkedChildren="开启" unCheckedChildren="关闭" />
            </Form.Item>}
            {
                dataShow && <>
                    <div style={{ display: 'flex' }}>
                        <p style={{ marginBottom: 5, marginLeft: 107 }}><strong style={{ marginRight: 20 }}>数据类型</strong></p>
                        <Form.Item name='conversionDataType'>
                            <Radio.Group>
                                {
                                    conversionList?.conversion_data_type?.map((item: { value: string; description: string; }, index: number) => {
                                        return <Radio.Button value={item.value} key={item.value}>{item.description}</Radio.Button>
                                    })
                                }
                            </Radio.Group>
                        </Form.Item>
                    </div>
                    {conversionDataType === 'CONVERSION_DATA_ADMETRIC' && <div style={{ display: 'flex' }}>
                        <p style={{ marginBottom: 5, marginLeft: 107 }}><strong style={{ marginRight: 20 }}>转化行为</strong></p>
                        <Form.Item name='conversionTargetType'>
                            <Radio.Group>
                                {
                                    conversionList?.conversion_target_type?.map((item: { value: string; description: string; }, index: number) => {
                                        return <Radio.Button value={item.value} key={item.value}>{item.description}</Radio.Button>
                                    })
                                }
                            </Radio.Group>
                        </Form.Item>
                    </div>}
                </>
            }
            {/* ============================================================视频结束页============================================================= */}
            {/* {pupState.sp_show && <Form.Item label={<strong>视频结束页</strong>} name='videoOver' valuePropName="checked">
                <Switch checkedChildren="开启" unCheckedChildren="关闭" />
            </Form.Item>}
            {
                videoOver && <>
                    <div style={{ display: 'flex' }}>
                        <p style={{ marginBottom: 5, marginLeft: 107 }}><strong style={{ marginRight: 20 }}>视频结束页类型</strong></p>
                        <Form.Item name='linkNameType'>
                            <Select style={{ width: 200 }} showSearch filterOption={(input, option) =>
                                (option!.children as unknown as string).toLowerCase().includes(input.toLowerCase())
                            } allowClear>
                                {
                                    linkNameList?.map((item: { link_name_type: string; description: string; }, index: number) => {
                                        return <Select.Option value={item.link_name_type} key={item.link_name_type}>{item.description}</Select.Option>
                                    })
                                }
                            </Select>
                        </Form.Item>
                    </div>
                    <div style={{ display: 'flex' }}>
                        <p style={{ marginBottom: 5, marginLeft: 107 }}><strong style={{ marginRight: 20 }}>结束文案</strong></p>
                        <Form.Item name='linkPageType'>
                            <Input placeholder='请输入结束页文案'/>
                        </Form.Item>
                    </div>
                </>
            }*/}
        </Form>
    </Modal >
}
export default CreativeModal